enterprise
==========

.. image:: https://img.shields.io/pypi/v/edx-enterprise.svg
    :target: https://pypi.python.org/pypi/edx-enterprise/
    :alt: PyPI

.. image:: https://travis-ci.org/edx/edx-enterprise.svg?branch=master
    :target: https://travis-ci.org/edx/edx-enterprise
    :alt: Travis

.. image:: http://codecov.io/github/edx/edx-enterprise/coverage.svg?branch=master
    :target: http://codecov.io/github/edx/edx-enterprise?branch=master
    :alt: Codecov

.. image:: http://edx-enterprise.readthedocs.io/en/latest/?badge=latest
    :target: http://open-edx-enterprise-service-documentation.readthedocs.io/en/latest/
    :alt: Documentation

.. image:: https://img.shields.io/pypi/pyversions/edx-enterprise.svg
    :target: https://pypi.python.org/pypi/edx-enterprise/
    :alt: Supported Python versions

.. image:: https://img.shields.io/github/license/edx/edx-enterprise.svg
    :target: https://github.com/edx/edx-enterprise/blob/master/LICENSE.txt
    :alt: License

The ``Open edx Enterprise Service`` app provides enterprise features to the Open
edX platform.  The majority of these features are structured around the concept
of an ``Enterprise Customer``, which is an organization or a group of people
that "consumes" courses published on the Open edX platform.

Documentation
-------------

Full documentation for the Open edX Enterprise Service can be found at
http://open-edx-enterprise-service-documentation.readthedocs.io/en/latest/.

License
-------

The code in this repository is licensed under the AGPL 3.0 unless otherwise noted.

Please see ``LICENSE.txt`` for details.

How To Contribute
-----------------

Contributions are very welcome.

Please read `How To Contribute <https://github.com/edx/edx-platform/blob/master/CONTRIBUTING.rst>`_ for details.

Even though they were written with ``edx-platform`` in mind, the guidelines
should be followed for Open edX code in general.

A Pull Request Description Template can be found at`PULL_REQUEST_TEMPLATE.md`_ - this
template is automatially applied when you open a pull request from GitHub.  Please
make sure to include this template if submitting a pull request via other channels.

.. _PULL_REQUEST_TEMPLATE.md: https://github.com/edx/edx-enterprise/blob/master/.github/PULL_REQUEST_TEMPLATE_TEMPLATE.md

After submitting a pull request, please use the Github "Reviewers" widget to add
relevant reviewers and track review process.

Reporting Security Issues
-------------------------

Please do not report security issues in public. Please email security@edx.org.

Getting Help
------------

Have a question about this repository, or about Open edX in general?  Please
refer to this `list of resources`_ if you need any assistance.

.. _list of resources: https://open.edx.org/getting-help
